Rev 3118: (bialix) XFAIL test for #174055: can't run bzr info while dirstate in file:///home/pqm/archives/thelove/bzr/%2Btrunk/
Canonical.com Patch Queue Manager
pqm at pqm.ubuntu.com
Sat Dec 15 21:00:30 GMT 2007
At file:///home/pqm/archives/thelove/bzr/%2Btrunk/
------------------------------------------------------------
revno: 3118
revision-id:pqm at pqm.ubuntu.com-20071215210020-m28kk1qmbcc9n6qs
parent: pqm at pqm.ubuntu.com-20071215200456-98e8x5v3iconkigg
parent: bialix at ukr.net-20071215183310-q5xcwedkn6bh2yjg
committer: Canonical.com Patch Queue Manager <pqm at pqm.ubuntu.com>
branch nick: +trunk
timestamp: Sat 2007-12-15 21:00:20 +0000
message:
(bialix) XFAIL test for #174055: can't run bzr info while dirstate
is locked
modified:
bzrlib/tests/blackbox/test_info.py test_info.py-20060215045507-bbdd2d34efab9e0a
------------------------------------------------------------
revno: 3113.5.1
revision-id:bialix at ukr.net-20071215183310-q5xcwedkn6bh2yjg
parent: pqm at pqm.ubuntu.com-20071214163914-dqiqxlhho36ce54r
committer: Alexander Belchenko <bialix at ukr.net>
branch nick: test.174055
timestamp: Sat 2007-12-15 20:33:10 +0200
message:
XFAIL test for #174055: can't run bzr info while dirstate is locked
modified:
bzrlib/tests/blackbox/test_info.py test_info.py-20060215045507-bbdd2d34efab9e0a
=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- a/bzrlib/tests/blackbox/test_info.py 2007-11-26 13:55:51 +0000
+++ b/bzrlib/tests/blackbox/test_info.py 2007-12-15 18:33:10 +0000
@@ -1146,12 +1146,15 @@
except errors.PathNotChild:
return path
- if tree_locked and sys.platform == 'win32':
- # We expect this to fail because of locking errors. (A write-locked
- # file cannot be read-locked in the same process).
+ if tree_locked:
+ # We expect this to fail because of locking errors.
+ # (A write-locked file cannot be read-locked
+ # in the different process -- either on win32 or on linux).
# This should be removed when the locking errors are fixed.
- self.run_bzr_error([], 'info ' + command_string)
- return
+ self.expectFailure('OS locks are exclusive '
+ 'for different processes (Bug #174055)',
+ self.run_bzr_subprocess,
+ 'info ' + command_string)
out, err = self.run_bzr('info %s' % command_string)
description = {
(True, True): 'Lightweight checkout',
More information about the bazaar-commits
mailing list